#
# spec file for package python-httpbin
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define modname httpbin
%{?sle15_python_module_pythons}
Name:           python-httpbin
Version:        0.10.1
Release:        1.2
Summary:        HTTP Request and Response Service
License:        MIT
URL:            https://github.com/psf/httpbin
Source:         https://files.pythonhosted.org/packages/source/h/%{modname}/%{modname}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM https://github.com/psf/httpbin/pull/29 Support Flask 3.0
Patch:          flask3.patch
BuildRequires:  %{python_module Brotli}
BuildRequires:  %{python_module Flask >= 2.2.4}
BuildRequires:  %{python_module Werkzeug >= 2.0}
BuildRequires:  %{python_module decorator}
BuildRequires:  %{python_module flasgger}
BuildRequires:  %{python_module gevent}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Brotli
Requires:       python-Flask >= 2.2.4
Requires:       python-Werkzeug >= 2.0
Requires:       python-decorator
Requires:       python-flasgger
Requires:       python-gevent
Requires:       python-six
BuildArch:      noarch
%python_subpackages

%description
httpbin(1): HTTP Request & Response Service

Testing an HTTP Library can become difficult sometimes.
RequestBin is fantastic for testing POST requests, but doesn't let
you control the response. This exists to cover
all kinds of HTTP scenarios. Additional endpoints are being considered.

All endpoint responses are JSON-encoded.

%prep
%autosetup -p1 -n %{modname}-%{version}
# we are running CPython, let us use Brotli instead of brotlicffi (they should be compatible)
sed -i 's/brotlicffi/brotli/' httpbin/filters.py

%build
export LANG=en_US.UTF-8
%pyproject_wheel

%install
export LANG=en_US.UTF-8
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/httpbin
%{python_sitelib}/httpbin-%{version}*-info

%changelog
* Tue Oct 24 2023 Markéta Machová <mmachova@suse.com>
- Use Brotli instead of dropped brotlicffi
* Thu Oct 19 2023 Markéta Machová <mmachova@suse.com>
- Repackage, new active upstream
  * In their words: We were unable to get ahold of the folks at postmanlabs to
    maintain the original project, and httpbin is used for other packages
    within the python ecosystem, such as pytest-httpbin which is in turn used
    by packages such as requests so we have forked this package. That means
    that httpbin.org is not actually backed by this repo, but the httpbin
    package is. Confusing right?
  * Drop now unneeded _service, changes in the *spec
- Update to 0.10.1
  * Override docker image port with HTTPBIN_PORT
  * A number of fixes for code rot, thanks @mgorny and @tjni
- Drop upstreamed/no-longer-needed patches:
  * fix-setup-py.patch
  * httpbin-pr674-wekzeug2.1.patch
  * werkzeug.patch
  * support-werkzeug-2.3.patch
- Add flask3.patch to support Flask 3.0
* Wed Jun 21 2023 Steve Kowalik <steven.kowalik@suse.com>
- Add patch support-werkzeug-2.3.patch, support Werkzeug 2.3.
  (bsc#1212557)
- Remove now unneeded blinker from {Build,}Requires.
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Fri Apr 22 2022 Ben Greiner <code@bnavigator.de>
- add httpbin-pr674-wekzeug2.1.patch for Werkzeug 2.1 compatibility
  gh#postmanlabs/httpbin#674
* Tue Apr 12 2022 Ben Greiner <code@bnavigator.de>
- Truncate werkzeug.patch as Flask changed their behavior back to
  returning relative URLs.
- Update fix-setup-py.patch accordingly
- Update _service file (rerun modifies the archive, but keeps same
  tag)
* Tue Mar 15 2022 Steve Kowalik <steven.kowalik@suse.com>
- Use of raven has been removed, drop it from {Build,}Requires.
- Add patch fix-setup-py.patch:
  * Drop raven and fix brotli in setup.py
* Wed Jun 23 2021 Steve Kowalik <steven.kowalik@suse.com>
- Modify werkzeug.patch to support Werkzeug 2.0, update Requires.
* Tue May 28 2019 Tomáš Chvátal <tchvatal@suse.com>
- Add patch to fix new werkzeug build, atm PR upstream:
  * werkzeug.patch
* Thu Mar 14 2019 tchvatal@suse.com
- Switch to service, upstream is now at release 0.9.2 but nobody
  bothers with tags, keep the last tagged/pypi release as a version
  and add all other stuff as git commit
- Update to version 0.7.0+git20181107.f8ec666:
  * Corrected repository URL in app.json.
  * remove duplicated "X-Forwarded-For" from ENV_HEADERS
  * Added Python 3.7 to Travis/Tox.
  * Removed httpbin.org link which is mentioned 3 times in README
* Tue Mar 12 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.7.0:
  * no upstream changelog
- Enable tests
- Add missing dependencies
* Tue Apr  4 2017 jmatejek@suse.com
- initial commit as test requirement for python-requests
